summaryrefslogtreecommitdiff
path: root/apt-pkg
diff options
context:
space:
mode:
authorMichael Vogt <michael.vogt@ubuntu.com>2008-02-01 16:55:44 +0100
committerMichael Vogt <michael.vogt@ubuntu.com>2008-02-01 16:55:44 +0100
commite06c72cd8d39433b04883f35dea81619b8464b0e (patch)
tree30d9f270d54b4081a8ffbaca15daf5f171052dca /apt-pkg
parent51dbf3686ee62584d7c2a21b6209a45ebceac5c9 (diff)
* apt-pkg/algorithms.cc:
- add APT::Update::Post-Invoke-Success script slot
Diffstat (limited to 'apt-pkg')
-rw-r--r--apt-pkg/algorithms.cc6
1 files changed, 5 insertions, 1 deletions
diff --git a/apt-pkg/algorithms.cc b/apt-pkg/algorithms.cc
index 57b85e24f..503a928ac 100644
--- a/apt-pkg/algorithms.cc
+++ b/apt-pkg/algorithms.cc
@@ -1371,7 +1371,11 @@ bool ListUpdate(pkgAcquireStatus &Stat,
return _error->Error(_("Some index files failed to download, they have been ignored, or old ones used instead."));
- // Run the scripts if all was fine
+ // Run the success scripts if all was fine
+ if(!TransientNetworkFailure && !Failed)
+ RunScripts("APT::Update::Post-Invoke-Success");
+
+ // Run the other scripts
RunScripts("APT::Update::Post-Invoke");
return true;
}